@@ -44,8 +44,6 @@ void QmlPlugins::registerTypes(const char* uri)
     qmlRegisterType<AvailableDevices>(uri, 0, 2, "AvailableDevices");
     // @uri org.kde.plasma.networkmanagement.ConnectionIcon
     qmlRegisterType<ConnectionIcon>(uri, 0, 2, "ConnectionIcon");
-    // @uri org.kde.plasma.networkmanagement.Configuration
-    qmlRegisterType<Configuration>(uri, 0, 2, "Configuration");
     // @uri org.kde.plasma.networkmanagement.EnabledConnections
     qmlRegisterType<EnabledConnections>(uri, 0, 2, "EnabledConnections");
     // @uri org.kde.plasma.networkmanagement.Enums
@@ -66,4 +64,10 @@ void QmlPlugins::registerTypes(const char* uri)
     qmlRegisterType<CreatableConnectionsModel>(uri, 0, 2, "CreatableConnectionsModel");
     // @uri org.kde.plasma.networkmanagement.MobileProxyModel
     qmlRegisterType<MobileProxyModel>(uri, 0, 2, "MobileProxyModel");
+
+    qmlRegisterSingletonType<Configuration>(uri, 0, 2, "Configuration", [](QQmlEngine *engine, QJSEngine *scriptEngine) -> QObject * {
+        Q_UNUSED(engine)
+        Q_UNUSED(scriptEngine)
+        return new Configuration;
+    });
 }
